:github_url: https://github.com/fabiangeisler/pyshotgrid/blob/master/src/pyshotgrid/sg_default_entities.py

SG default entities
===================

.. automodule:: pyshotgrid.sg_default_entities
    :members:
